﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Script.Serialization;



public static class MyExtension
{
	/// <summary>
	/// 将一个字符串转成为一个整数，如果转换失败，返回 0
	/// </summary>
	/// <param name="str"></param>
	/// <returns></returns>
	public static int TryToInt(this string str)
	{
		return TryToInt(str, 0);
	}

	/// <summary>
	/// 将一个字符串转成为一个整数，可指定默认值。
	/// </summary>
	/// <param name="str"></param>
	/// <param name="defaultVal"></param>
	/// <returns></returns>
	public static int TryToInt(this string str, int defaultVal)
	{
		int result = defaultVal;
		int.TryParse(str, out result);
		return result;
	}


	/// <summary>
	/// 将一个对象序列化成 JSON 格式字符串
	/// </summary>
	/// <param name="obj"></param>
	/// <returns></returns>
	public static string ToJson(this object obj)
	{
		if( obj == null )
			return string.Empty;

		JavaScriptSerializer jss = new JavaScriptSerializer();
		return jss.Serialize(obj);
	}

	/// <summary>
	/// 从JSON字符串中反序列化对象
	/// </summary>
	/// <typeparam name="T"></typeparam>
	/// <param name="cookie"></param>
	/// <returns></returns>
	public static T FromJson<T>(this string cookie)
	{
		if( string.IsNullOrEmpty(cookie) )
			return default(T);

		JavaScriptSerializer jss = new JavaScriptSerializer();
		return jss.Deserialize<T>(cookie);
	}

}
